@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,6 +107,61 @@ void add_firestarter_user_pre()
     g_free(conf);
 }
 
+/* Change firestarters INIF configuration line to use br0 */
+/* INIF="br0" is the internal network interface when bridged. */
+void switch_firestarter_internal_interface()
+{
+    FILE *fp;
+    long file_size = 0;
+    char *line, *new_conf;
+    gchar *cmd, *info;
+
+    if((fp=fopen(FIRESTARTER_CONFIG, "r"))==NULL)
+    {
+	/* Dont show a popup */
+	return;
+    }
+    fseek(fp, 0, SEEK_END);
+    file_size = ftell(fp);
+    rewind(fp);
+
+    line = allocate(file_size+1);
+    new_conf = allocate(file_size+1024);
+
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+        if( cmplowercase(line, "inif=") )
+	{
+	   strcat(new_conf, "INIF=\"br0\"\n");
+	}
+	else
+	  strcat(new_conf, line);
+    }
+    fclose(fp);
+    free(line);
+
+    /* Write a new configuration with the altered INIF setting */
+    if((fp=fopen(FIRESTARTER_CONFIG, "w+"))==NULL)
+    {
+	/* Show a popup */
+	free(new_conf);
+	return;
+    }
+    fputs(new_conf, fp);
+    fclose(fp);
+    free(new_conf);
+
+    /* Reconfigure firestarter to use the new setting */
+    cmd = g_strdup_printf("%s --generate-scripts", FIRESTARTER_BINARY);
+    if( ! run_command(cmd) )
+    {
+	info = g_strdup_printf(_("Error reconfiguring firestarters configuration with this command:\n%s\n"), cmd);
+	show_info(info);
+	g_free(info);
+    }
+    g_free(cmd);
+}
 
 
 void apply_server_settings(struct w *widgets)
@@ -264,10 +319,6 @@ void apply_server_settings(struct w *widgets)
     /* Chroot is standard */
 
 
-    /* Add Firestarter iptables tap+ settings to the user-pre file if it exists */
-    add_firestarter_user_pre();
-
-
     /* Sysinit script parts to add if internet sharing is specified. */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[7]));
     if( active_index == 1 )
@@ -292,17 +343,29 @@ void apply_server_settings(struct w *widgets)
       share_internet = g_strdup_printf("%s\n", IP_FORWARD_CMD_STOP);
 
 
-    /* Sysinit script parts to add if Firestarter is used. */
+    /* If Firestarter is used, add sysinit script parts and setup firestarter. */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[8]));
     if( active_index == 1 )
     {
+	/* Add Firestarter iptables tap+ settings to
+           the user-pre file if it exists */
+	add_firestarter_user_pre();
+
+	/* Switches Firestarters internal interface to
+           br0 in the configuration file if it exists */
+	switch_firestarter_internal_interface();
+
+	/* Start script part for Firestarter */    
 	firestarter_start = g_strconcat(
-	"# Start Firestarter if its not running.\n",
+	"# Update Firestarter scripts and start Firestarter if its not running.\n",
 	"if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+	"    ", FIRESTARTER_BINARY, " --generate-scripts\n",
 	"    ", FIRESTARTER_BINARY, " -s\n",
 	"fi\n",
+	share_internet,
 	NULL);
 
+	/* Stop script part for Firestarter */    
 	firestarter_stop = g_strconcat(
 	"# Stop Firestarter if its running.\n",
 	"if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
@@ -330,9 +393,8 @@ void apply_server_settings(struct w *widgets)
 	"iptables -D INPUT  -i tap+ -j ACCEPT\n",
 	"iptables -D OUTPUT -o tap+ -j ACCEPT\n",
 	"iptables -D FORWARD -i tap+ -j ACCEPT\n",
-	"ifconfig ", lan_iface_name, "down\n",
-	"ifconfig ", lan_iface_name, "up\n",
-	share_internet,
+	"ifconfig ", lan_iface_name, " down\n",
+	"ifconfig ", lan_iface_name, " up\n",
 	NULL);
 	/* Dont remove any internet sharing. */
 	
@@ -384,6 +446,7 @@ void apply_server_settings(struct w *widgets)
     "chroot ", OPENVPN_SYSCONF_DIR, "/server\n",
     "server-bridge ", lan_iface_address," ", lan_subnet_mask," ", client_address_range,"\n",
     "duplicate-cn\n",
+    "client-config-dir ccd\n",
     "keepalive ", ping_interval, " ", ping_timeout, "\n",
     "max-clients ", max_clients, "\n",
     "user ", server_user, "\n",
@@ -531,7 +594,7 @@ void apply_server_settings(struct w *widgets)
     "\n",
     "ifconfig $br $lan_iface_ip netmask $lan_iface_netmask broadcast $lan_iface_broadcast\n",
     "\n",
-    "openvpn --daemon --writepid /var/run/openvpn/openvpn.pid \\\n",
+    "openvpn --daemon --script-security 2 --writepid /var/run/openvpn/openvpn.pid \\\n",
     "--config ", OPENVPN_SYSCONF_DIR, "/server/gadmin-openvpn-server.conf --cd ", OPENVPN_SYSCONF_DIR, "/server\n",
     "\n",
     firestarter_start,
@@ -561,7 +624,7 @@ void apply_server_settings(struct w *widgets)
     "\n",
     NULL);
 
-    /* Put the script with the others as: /etc/rc.d/init.d/gadmin-openvpn-server  */
+    /* Put the script with the others as: /etc/init.d/gadmin-openvpn-server  */
     sysinit_script_path = g_strdup_printf("%s/gadmin-openvpn-server", SYSINIT_SCRIPTS_DIR);
     if((fp=fopen(sysinit_script_path, "w+"))==NULL)
     {
