@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,25 +90,25 @@ void create_server_settings(struct w *widgets)
     /* LAN interface address */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN interface address: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("IE: 192.168.10.100\nYour LAN should not have the same network address as connecting clients commonly have, IE: 192.168.0 or 10.0.0. Also change this setting in your DHCP server and firewall."), NULL);
+    _("IE: 10.8.0.100\nYour LAN should not have the same network address as connecting clients commonly have, IE: 192.168.0.1 or 10.0.0.1 Also change this setting in your DHCP server and firewall."), NULL);
     a++; b++; ent++;
 
     /* LAN Subnet mask */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN subnet mask: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("IE: 255.255.255.0"), NULL);
+    _("IE: 255.255.0.0"), NULL);
     a++; b++; ent++;
 
     /* LAN Broadcast address */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN broadcast address: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("IE: 192.168.10.255"), NULL);
+    _("IE: 10.8.0.255"), NULL);
     a++; b++; ent++;
 
     /* VPN Clients address pool */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Client address range: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("VPN clients are assigned IP-addresses on the LAN in this range, IE: 192.168.10.120 192.168.10.254"), NULL);
+    _("VPN clients are assigned IP-addresses on the LAN in this range, IE: 10.8.0.120 10.8.255.254"), NULL);
     a++; b++; ent++;
 
     /* Protocol UDP/TCP */
