@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( ! strcmp(username, tempname) )
 			{
@@ -146,7 +146,7 @@ user_exists(G_CONST_RETURN gchar *username)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(username, tempname) 
 			&& strlen(username) == strlen(tempname) )
@@ -196,7 +196,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( ! strcmp(groupname, tempname) )
 			{
@@ -231,7 +231,7 @@ group_exists(G_CONST_RETURN gchar *groupname)
 		{
 		    if(check_buffer[x]==':')
 		    {
-			sprintf(tempname, check_buffer);
+			sprintf(tempname, "%s", check_buffer);
 			tempname[x]='\0';
 			if( strstr(groupname, tempname) && strlen(groupname)==strlen(tempname) )
 			{
@@ -881,8 +881,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 106;
     	  
-	    if( u_arr[where]!="0" && u_arr[where]!="1" && u_arr[where]!="2" && u_arr[where]!="3" && u_arr[where]!="4"
-	    &&  u_arr[where]!="5" && u_arr[where]!="6" && u_arr[where]!="7" && u_arr[where]!="8" && u_arr[where]!="9" )
+	    if( ! chars_are_digits(u_arr[where]) )
 	    {
 		strcpy(rnd_string, u_arr[where]);
                 break;
@@ -893,8 +892,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 53;
 
-            if( l_arr[where]!="0" && l_arr[where]!="1" && l_arr[where]!="2" && l_arr[where]!="3" && l_arr[where]!="4"
-	    &&  l_arr[where]!="5" && l_arr[where]!="6" && l_arr[where]!="7" && l_arr[where]!="8" && l_arr[where]!="9" )
+	    if( ! chars_are_digits(l_arr[where]) )
 	    {
 		strcpy(rnd_string, l_arr[where]);
     	        break;
@@ -925,3 +923,101 @@ char *random_string(int len)
 
     return rnd_string;
 }
+
+
+/* Write a client config file (ccd) for this user
+   in /etc/gadmin-openvpn/server/ccd/UserNameHere */
+void write_client_ccd_file(struct w *widgets, G_CONST_RETURN gchar *username)
+{
+    FILE *fp;
+    gchar *path;
+    long z = 0, lines = 0;
+    GtkTextBuffer *textbuffer;
+    GtkTextIter start, end;
+    gchar *ccd_text = NULL;
+    gchar **ccd_list = NULL;
+             
+    path = g_strdup_printf("%s/server/ccd", OPENVPN_SYSCONF_DIR);
+
+    /* Create the ccd directory if it doesnt exist */
+    if( ! file_exists(path) )
+    {
+	make_dir_chmod(path, "600"); /* Only accessible by root */
+    }
+    g_free(path);    
+
+    path = g_strdup_printf("%s/server/ccd/%s", OPENVPN_SYSCONF_DIR, username);
+    if((fp=fopen(path, "w+"))==NULL)
+    {
+        printf("Could not write client ccd file: %s\n", path);
+	g_free(path);
+        return;
+    }
+
+    /* Insert text from the ccd textview if any */
+    textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widgets->ccd_textview));
+    gtk_text_buffer_get_bounds(textbuffer, &start, &end);
+
+    ccd_text = gtk_text_iter_get_text(&start, &end);    
+    if( ccd_text!=NULL && strlen(ccd_text) > 0 )
+    {    
+    	ccd_list = g_strsplit(ccd_text, "\n", 0);
+	if( ccd_list!=NULL )
+	{
+    	    for(z=0; ccd_list[z]!=NULL; z++)
+	    {
+		/* Dont add a new line after the last row of text */
+		if( strlen(ccd_list[z]) < 1 && ccd_list[z+1] == NULL )
+    		  break;
+
+		fputs(ccd_list[z], fp);
+		fputs("\n", fp);
+		lines++;
+	    }	
+    	    g_strfreev(ccd_list);
+	}
+    }
+    if( ccd_text!=NULL )
+      g_free(ccd_text);
+                        		    				    			    		              
+    fclose(fp);
+
+    if( lines < 1 )
+      unlink(path);
+
+    g_free(path);
+}
+
+
+/* Get ccd file contents for a username or NULL */
+char * get_ccd_text(G_CONST_RETURN gchar *username)
+{
+    FILE *fp;
+    gchar *path;
+    long file_size = 0;
+    char *line, *ccd_contents = NULL;
+
+    path = g_strdup_printf("%s/server/ccd/%s", OPENVPN_SYSCONF_DIR, username);
+    if((fp=fopen(path, "r"))==NULL)
+    {
+	g_free(path);
+        return NULL;
+    }
+    fseek(fp, 0, SEEK_END);
+    file_size = ftell(fp);
+    rewind(fp);
+
+    line = allocate(file_size+1);
+    ccd_contents = allocate(file_size+1);
+                                                                    
+    if( file_size > 1 )
+    while(fgets(line, file_size, fp)!=NULL)
+    {
+	strcat(ccd_contents, line);
+    }
+    fclose(fp);
+    free(line);
+    g_free(path);
+
+    return ccd_contents;
+}
