@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@ void populate_server_settings(struct w *widgets)
     FILE *fp;
     int i = 0, x = 0, have_sysinit_script = 0;
     int share_internet = 0;
+    int have_firestarter_line = 0;
     long val = 0, file_size = 0;
     char *line, *tmp;
     gchar *info, *utf8 = NULL;
@@ -61,12 +62,6 @@ void populate_server_settings(struct w *widgets)
 	else
 	  gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[i]), 0);
     }
-    /* If Firestarter exists the default is to use it. */
-    if( file_exists(FIRESTARTER_USER_PRE) )
-      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 1);
-    else
-      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 0);
-
 
     /* Insert values from gadmin-openvpn-server.conf */
     openvpn_server_conf = g_strdup_printf("%s/server/gadmin-openvpn-server.conf", OPENVPN_SYSCONF_DIR);
@@ -151,7 +146,7 @@ void populate_server_settings(struct w *widgets)
 	    if( tmp[strlen(tmp)-1]=='\n')
 	      tmp[strlen(tmp)-1]='\0';
 
-	    for(i=i; tmp[i]!='\0'; i++)
+	    for(i=0; tmp[i]!='\0'; i++)
 	      if( tmp[i]==' ' && tmp[i-1]!=' ' )
 	        break;
 	    tmp[i]='\0';
@@ -286,7 +281,7 @@ void populate_server_settings(struct w *widgets)
 	&&  cmplowercase(line, "auth-pam.so")
 	&&  cmplowercase(line, "login") )
 	{
-		gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 1);
+	    gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[2]), 1);
 	}
 
 	/* Combo: Encryption type */
@@ -582,7 +577,7 @@ void populate_server_settings(struct w *widgets)
 	          g_free(utf8);
 	    }
 
-	    /* Share internet (Note: lower case comparizon) */
+	    /* Share internet. */
 	    if( cmplowercase(line, "iptables -t nat -a postrouting -s") )
 	    {
 		share_internet = 1;
@@ -592,6 +587,7 @@ void populate_server_settings(struct w *widgets)
 	    if( cmplowercase(line, "firestarter -s") )
 	    {
 		gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 1);
+		have_firestarter_line = 1;
 	    }
 	}
 	fclose(fp);
@@ -604,6 +600,10 @@ void populate_server_settings(struct w *widgets)
     if( ! share_internet )
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 0);
 
+    if( ! have_firestarter_line )
+	gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[8]), 0);
+
+
     /* Set standard options if theres no sysinit script */
     if( ! have_sysinit_script )
     {
@@ -621,7 +621,7 @@ void populate_server_settings(struct w *widgets)
 	if( utf8!=NULL )
           g_free(utf8);
 
-	snprintf(tmp, 1000, "%s", "192.168.10.255");
+	snprintf(tmp, 1000, "%s", "10.8.0.255");
 	utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
 	gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[5]), utf8);
 	if( utf8!=NULL )
