@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,10 +34,10 @@ extern int activated;
 
 void reread_conf(struct w *widgets)
 {
-    /* Update configuration and reread with a HUP. Show any errors */
-//    gchar *cmd, *test;
-
     if( ! activated )
       return;
 
+    init_stop(widgets);
+
+    init_start(widgets);
 }
